@@ -1,6 +1,6 @@
 '''Non cryptic XML/HTML parsing'''
 
-__version__ = "0.0.5"
+__version__ = "0.0.7"
 
 _author = 'Di Paola Martin'
 _license = 'GNU GPLv3'
@@ -26,6 +26,6 @@ try:
     from .selectq import Selection, Selector
     from .browsers import FileBrowser, WebBrowser
     from .predicates import Attr, Value, Text
-    from .shortcuts import open_browser
-except SystemError:
+    from .shortcuts import open_browser, wait_for
+except ImportError:
     pass  # this happens when importing from setup.py
